@@ -996,7 +996,10 @@ class TrocketClient(AbstractClient):
     def DescribeMigratingTopicList(self, request):
         """查询Topic迁移状态列表
 
-        查询过滤器，支持TopicName、MigrationStatus、Namespace查询
+        Filters字段为查询过滤器，支持以下条件：
+        TopicName 主题名称，支持模糊查询，
+        MigrationStatus 迁移状态，可参考MigratingTopic数据结构，
+        Namespace 命名空间，仅4.x集群有效，
 
         :param request: Request instance for DescribeMigratingTopicList.
         :type request: :class:`tencentcloud.trocket.v20230308.models.DescribeMigratingTopicListRequest`
@@ -1117,10 +1120,39 @@ class TrocketClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeSmoothMigrationTaskList(self, request):
+        """用于查询平滑迁移任务列表
+
+        查询参数Filters， 支持的字段如下：
+        TaskStatus, 任务状态，支持多选
+        ConnectionType，网络连接类型，支持多选
+        InstanceId，实例ID，精确搜索
+        TaskName，任务名称，支持模糊搜索
+
+        :param request: Request instance for DescribeSmoothMigrationTaskList.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.DescribeSmoothMigrationTaskListRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.DescribeSmoothMigrationTaskListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeSmoothMigrationTaskList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeSmoothMigrationTaskListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeSourceClusterGroupList(self, request):
         """平滑迁移过程获取源集群group列表接口
 
-        查询过滤器，支持字段
+        Filters字段为查询过滤器，支持以下字段：
         GroupName，消费组名称模糊搜索
         Imported，是否已导入
         ImportStatus，导入状态
